#!/usr/bin/env node

'use strict';

/**
 * Dependencies
 */

const readFile = require('fs').readFileSync;
const build = require('cloudconfig');
const meow = require('meow');
const co = require('co');


/**
 * CLI
 */

let cli = meow({
  help: [
    'Usage',
    '    cloudconfig -f config.json',
    '    cat config.json | cloudconfig',
    ''
  ]
});

if (cli.flags.h || cli.flags.help) {
  return cli.showHelp();
}

co(function * () {
  let config = yield readConfig();
  let source = yield build(config);

  console.log(source);
}).catch(function (err) {
  console.error(err.stack);
  process.exit(1);
});

/**
 * Helpers
 */

function readConfig () {
  return new Promise(function (resolve) {
    let config = '';

    // if -f or --file is set
    // read from path
    let path = cli.flags.f || cli.flags.file;

    if (path) {
      config = readFile(path, 'utf-8');
      config = JSON.parse(config);

      return resolve(config);
    }

    // read from stdin
    process.stdin.on('data', function (data) {
      config += data;
    });

    process.stdin.on('end', function () {
      config = JSON.parse(config);

      resolve(config);
    });
  });
}
